

class FeatureSettings:
    @classmethod
    def keys_to_snakecase(cls, data: dict) -> dict:
        return {
            'engine_settings': data['engine-settings']
        }

    def __init__(
            self,
            service_id: int = None,
            engine_settings: str = None,
            **kwargs
    ):
        self.engine_settings = engine_settings
        self.service_id = service_id
        for k, v in kwargs.items():
            self.__dict__[k] = v

    def __repr__(self):
        params = [f"{k}={repr(v)}" for k, v in self.__dict__.items()]
        return f"<{self.__class__.__name__}({', '.join(params)})>"





class GameIni:

    @classmethod
    def keys_to_snake_case(cls, data: dict) -> dict:
        return {
            'dino_spawn_weight_multipliers': data['DinoSpawnWeightMultipliers'],
            'override_engram_entries': data['OverrideEngramEntries'],
            'level_experience_ramp_overrides': data['LevelExperienceRampOverrides'],
            'override_player_level_engram_points': data['OverridePlayerLevelEngramPoints'],
            'tamed_dino_class_damage_multipliers': data['TamedDinoClassDamageMultipliers'],
            'tamed_dino_class_resistance_multipliers': data['TamedDinoClassResistanceMultipliers'],
            'exclude_item_indices': data['ExcludeItemIndices'],
            'harvest_resource_item_amount_class_multipliers': data['HarvestResourceItemAmountClassMultipliers'],
            'override_named_engram_entries': data['OverrideNamedEngramEntries'],
            'b_only_allow_specified_engrams': data['bOnlyAllowSpecifiedEngrams'],
            'global_spoiling_time_multiplier': data['GlobalSpoilingTimeMultiplier'],
            'global_item_decomposition_time_multiplier': data['GlobalItemDecompositionTimeMultiplier'],
            'global_corpse_decomposition_time_multiplier': data['GlobalCorpseDecompositionTimeMultiplier'],
            'override_max_experience_points_player': data['OverrideMaxExperiencePointsPlayer'],
            'override_max_experience_points_dino': data['OverrideMaxExperiencePointsDino'],
            'pv_p_zone_structure_damage_multiplier': data['PvPZoneStructureDamageMultiplier'],
            'b_pv_e_disable_friendly_fire': data['bPvEDisableFriendlyFire'],
            'resource_no_replenish_radius_players': data['ResourceNoReplenishRadiusPlayers'],
            'resource_no_replenish_radius_structures': data['ResourceNoReplenishRadiusStructures'],
            'b_auto_pv_e_timer': data['bAutoPvETimer'],
            'b_auto_pv_e_use_system_time': data['bAutoPvEUseSystemTime'],
            'auto_pv_e_start_time_seconds': data['AutoPvEStartTimeSeconds'],
            'auto_pv_e_stop_time_seconds': data['AutoPvEStopTimeSeconds'],
            'lay_egg_interval_multiplier': data['LayEggIntervalMultiplier'],
            'dino_turret_damage_multiplier': data['DinoTurretDamageMultiplier'],
            'b_disable_loot_crates': data['bDisableLootCrates'],
            'dino_harvesting_damage_multiplier': data['DinoHarvestingDamageMultiplier'],
            'b_disable_friendly_fire': data['bDisableFriendlyFire'],
            'custom_recipe_effectiveness_multiplier': data['CustomRecipeEffectivenessMultiplier'],
            'custom_recipe_skill_multiplier': data['CustomRecipeSkillMultiplier'],
            'mating_interval_multiplier': data['MatingIntervalMultiplier'],
            'egg_hatch_speed_multiplier': data['EggHatchSpeedMultiplier'],
            'baby_mature_speed_multiplier': data['BabyMatureSpeedMultiplier'],
            'b_passive_defenses_damage_riderless_dinos': data['bPassiveDefensesDamageRiderlessDinos'],
            'kill_x_p_multiplier': data['KillXPMultiplier'],
            'harvest_x_p_multiplier': data['HarvestXPMultiplier'],
            'craft_x_p_multiplier': data['CraftXPMultiplier'],
            'generic_x_p_multiplier': data['GenericXPMultiplier'],
            'special_x_p_multiplier': data['SpecialXPMultiplier'],
            'p_g_map_name': data['PGMapName'],
            'p_g_terrain_properties_string': data['PGTerrainPropertiesString'],
            'config_override_supply_crate_items': data['ConfigOverrideSupplyCrateItems'],
            'b_disable_dino_riding': data['bDisableDinoRiding'],
            'b_disable_dino_taming': data['bDisableDinoTaming'],
            'b_use_corpse_locator': data['bUseCorpseLocator'],
            'b_disable_structure_placement_collision': data['bDisableStructurePlacementCollision'],
            'fast_decay_interval': data['FastDecayInterval'],
            'b_use_singleplayer_settings': data['bUseSingleplayerSettings'],
            'b_allow_unlimited_respecs': data['bAllowUnlimitedRespecs'],
            'supply_crate_loot_quality_multiplier': data['SupplyCrateLootQualityMultiplier'],
            'fishing_loot_quality_multiplier': data['FishingLootQualityMultiplier'],
            'per_level_stats_multiplier': data['PerLevelStatsMultiplier'],
            'baby_cuddle_interval_multiplier': data['BabyCuddleIntervalMultiplier'],
            'baby_cuddle_grace_period_multiplier': data['BabyCuddleGracePeriodMultiplier'],
            'baby_cuddle_lose_imprint_quality_speed_multiplier': data['BabyCuddleLoseImprintQualitySpeedMultiplier'],
            'baby_imprinting_stat_scale_multiplier': data['BabyImprintingStatScaleMultiplier'],
            'player_harvesting_damage_multiplier': data['PlayerHarvestingDamageMultiplier'],
            'crop_growth_speed_multiplier': data['CropGrowthSpeedMultiplier'],
            'baby_food_consumption_speed_multiplier': data['BabyFoodConsumptionSpeedMultiplier'],
            'dino_class_damage_multipliers': data['DinoClassDamageMultipliers'],
            'b_pv_e_allow_tribe_war': data['bPvEAllowTribeWar'],
            'b_pv_e_allow_tribe_war_cancel': data['bPvEAllowTribeWarCancel'],
            'crop_decay_speed_multiplier': data['CropDecaySpeedMultiplier'],
            'hair_growth_speed_multiplier': data['HairGrowthSpeedMultiplier'],
            'fuel_consumption_interval_multiplier': data['FuelConsumptionIntervalMultiplier'],
            'kick_idle_players_period': data['KickIdlePlayersPeriod'],
            'max_number_of_players_in_tribe': data['MaxNumberOfPlayersInTribe'],
            'use_corpse_life_span_multiplier': data['UseCorpseLifeSpanMultiplier'],
            'global_powered_battery_durability_decrease_per_second': data['GlobalPoweredBatteryDurabilityDecreasePerSecond'],
            'b_limit_turrets_in_range': data['bLimitTurretsInRange'],
            'limit_turrets_range': data['LimitTurretsRange'],
            'limit_turrets_num': data['LimitTurretsNum'],
            'b_hard_limit_turrets_in_range': data['bHardLimitTurretsInRange'],
            'b_show_creative_mode': data['bShowCreativeMode'],
            'prevent_offline_pv_p_connection_invincible_interval': data['PreventOfflinePvPConnectionInvincibleInterval'],
            'tamed_dino_character_food_drain_multiplier': data['TamedDinoCharacterFoodDrainMultiplier'],
            'wild_dino_character_food_drain_multiplier': data['WildDinoCharacterFoodDrainMultiplier'],
            'wild_dino_torpor_drain_multiplier': data['WildDinoTorporDrainMultiplier'],
            'passive_tame_interval_multiplier': data['PassiveTameIntervalMultiplier'],
            'tamed_dino_torpor_drain_multiplier': data['TamedDinoTorporDrainMultiplier'],
            'b_ignore_structures_prevention_volumes': data['bIgnoreStructuresPreventionVolumes'],
            'b_genesis_use_structures_prevention_volumes': data['bGenesisUseStructuresPreventionVolumes'],
            'b_disable_genesis_missions': data['bDisableGenesisMissions'],
            'baby_imprint_amount_multiplier': data['BabyImprintAmountMultiplier'],
            'hexagon_reward_multiplier': data['HexagonRewardMultiplier'],
            'b_allow_flyer_speed_leveling': data['bAllowFlyerSpeedLeveling'],
            'prevent_transfer_for_class_names': data['PreventTransferForClassNames'],
        }

    def __init__(
            self,
            service_id: int = None,
            dino_spawn_weight_multipliers: str = None,
            override_engram_entries: str = None,
            level_experience_ramp_overrides: str = None,
            override_player_level_engram_points: str = None,
            tamed_dino_class_damage_multipliers: str = None,
            tamed_dino_class_resistance_multipliers: str = None,
            exclude_item_indices: str = None,
            harvest_resource_item_amount_class_multipliers: str = None,
            override_named_engram_entries: str = None,
            b_only_allow_specified_engrams: str = None,
            global_spoiling_time_multiplier: str = None,
            global_item_decomposition_time_multiplier: str = None,
            global_corpse_decomposition_time_multiplier: str = None,
            override_max_experience_points_player: str = None,
            override_max_experience_points_dino: str = None,
            pvp_zone_structure_damage_multiplier: str = None,
            b_pve_disable_friendly_fire: str = None,
            resource_no_replenish_radius_players: str = None,
            resource_no_replenish_radius_structures: str = None,
            b_auto_pve_timer: str = None,
            b_auto_pve_use_system_time: str = None,
            auto_pve_start_time_seconds: str = None,
            auto_pve_stop_time_seconds: str = None,
            lay_egg_interval_multiplier: str = None,
            dino_turret_damage_multiplier: str = None,
            b_disable_loot_crates: str = None,
            dino_harvesting_damage_multiplier: str = None,
            b_disable_friendly_fire: str = None,
            custom_recipe_effectiveness_multiplier: str = None,
            custom_recipe_skill_multiplier: str = None,
            mating_interval_multiplier: str = None,
            egg_hatch_speed_multiplier: str = None,
            baby_mature_speed_multiplier: str = None,
            b_passive_defenses_damage_riderless_dinos: str = None,
            kill_xp_multiplier: str = None,
            harvest_xp_multiplier: str = None,
            craft_xp_multiplier: str = None,
            generic_xp_multiplier: str = None,
            special_xp_multiplier: str = None,
            pg_map_name: str = None,
            pg_terrain_properties_string: str = None,
            config_override_supply_crate_items: str = None,
            b_disable_dino_riding: str = None,
            b_disable_dino_taming: str = None,
            b_use_corpse_locator: str = None,
            b_disable_structure_placement_collision: str = None,
            fast_decay_interval: str = None,
            b_use_singleplayer_settings: str = None,
            b_allow_unlimited_respecs: str = None,
            supply_crate_loot_quality_multiplier: str = None,
            fishing_loot_quality_multiplier: str = None,
            per_level_stats_multiplier: str = None,
            baby_cuddle_interval_multiplier: str = None,
            baby_cuddle_grace_period_multiplier: str = None,
            baby_cuddle_lose_imprint_quality_speed_multiplier: str = None,
            baby_imprinting_stat_scale_multiplier: str = None,
            player_harvesting_damage_multiplier: str = None,
            crop_growth_speed_multiplier: str = None,
            baby_food_consumption_speed_multiplier: str = None,
            dino_class_damage_multipliers: str = None,
            b_pve_allow_tribe_war: str = None,
            b_pve_allow_tribe_war_cancel: str = None,
            crop_decay_speed_multiplier: str = None,
            hair_growth_speed_multiplier: str = None,
            fuel_consumption_interval_multiplier: str = None,
            kick_idle_players_period: str = None,
            max_number_of_players_in_tribe: str = None,
            use_corpse_life_span_multiplier: str = None,
            global_powered_battery_durability_decrease_per_second: str = None,
            b_limit_turrets_in_range: str = None,
            limit_turrets_range: str = None,
            limit_turrets_num: str = None,
            b_hard_limit_turrets_in_range: str = None,
            b_show_creative_mode: str = None,
            prevent_offline_pvp_connection_invincible_interval: str = None,
            tamed_dino_character_food_drain_multiplier: str = None,
            wild_dino_character_food_drain_multiplier: str = None,
            wild_dino_torpor_drain_multiplier: str = None,
            passive_tame_interval_multiplier: str = None,
            tamed_dino_torpor_drain_multiplier: str = None,
            b_ignore_structures_prevention_volumes: str = None,
            b_genesis_use_structures_prevention_volumes: str = None,
            b_disable_genesis_missions: str = None,
            baby_imprint_amount_multiplier: str = None,
            hexagon_reward_multiplier: str = None,
            b_allow_flyer_speed_leveling: str = None,
            prevent_transfer_for_class_names: str = None,
            **kwargs
    ):
        self.service_id = service_id
        self.dino_spawn_weight_multipliers = dino_spawn_weight_multipliers
        self.override_engram_entries = override_engram_entries
        self.level_experience_ramp_overrides = level_experience_ramp_overrides
        self.override_player_level_engram_points = override_player_level_engram_points
        self.tamed_dino_class_damage_multipliers = tamed_dino_class_damage_multipliers
        self.tamed_dino_class_resistance_multipliers = tamed_dino_class_resistance_multipliers
        self.exclude_item_indices = exclude_item_indices
        self.harvest_resource_item_amount_class_multipliers = harvest_resource_item_amount_class_multipliers
        self.override_named_engram_entries = override_named_engram_entries
        self.b_only_allow_specified_engrams = b_only_allow_specified_engrams
        self.global_spoiling_time_multiplier = global_spoiling_time_multiplier
        self.global_item_decomposition_time_multiplier = global_item_decomposition_time_multiplier
        self.global_corpse_decomposition_time_multiplier = global_corpse_decomposition_time_multiplier
        self.override_max_experience_points_player = override_max_experience_points_player
        self.override_max_experience_points_dino = override_max_experience_points_dino
        self.pv_p_zone_structure_damage_multiplier = pvp_zone_structure_damage_multiplier
        self.b_pv_e_disable_friendly_fire = b_pve_disable_friendly_fire
        self.resource_no_replenish_radius_players = resource_no_replenish_radius_players
        self.resource_no_replenish_radius_structures = resource_no_replenish_radius_structures
        self.b_auto_pv_e_timer = b_auto_pve_timer
        self.b_auto_pv_e_use_system_time = b_auto_pve_use_system_time
        self.auto_pv_e_start_time_seconds = auto_pve_start_time_seconds
        self.auto_pv_e_stop_time_seconds = auto_pve_stop_time_seconds
        self.lay_egg_interval_multiplier = lay_egg_interval_multiplier
        self.dino_turret_damage_multiplier = dino_turret_damage_multiplier
        self.b_disable_loot_crates = b_disable_loot_crates
        self.dino_harvesting_damage_multiplier = dino_harvesting_damage_multiplier
        self.b_disable_friendly_fire = b_disable_friendly_fire
        self.custom_recipe_effectiveness_multiplier = custom_recipe_effectiveness_multiplier
        self.custom_recipe_skill_multiplier = custom_recipe_skill_multiplier
        self.mating_interval_multiplier = mating_interval_multiplier
        self.egg_hatch_speed_multiplier = egg_hatch_speed_multiplier
        self.baby_mature_speed_multiplier = baby_mature_speed_multiplier
        self.b_passive_defenses_damage_riderless_dinos = b_passive_defenses_damage_riderless_dinos
        self.kill_x_p_multiplier = kill_xp_multiplier
        self.harvest_x_p_multiplier = harvest_xp_multiplier
        self.craft_x_p_multiplier = craft_xp_multiplier
        self.generic_x_p_multiplier = generic_xp_multiplier
        self.special_x_p_multiplier = special_xp_multiplier
        self.p_g_map_name = pg_map_name
        self.p_g_terrain_properties_string = pg_terrain_properties_string
        self.config_override_supply_crate_items = config_override_supply_crate_items
        self.b_disable_dino_riding = b_disable_dino_riding
        self.b_disable_dino_taming = b_disable_dino_taming
        self.b_use_corpse_locator = b_use_corpse_locator
        self.b_disable_structure_placement_collision = b_disable_structure_placement_collision
        self.fast_decay_interval = fast_decay_interval
        self.b_use_singleplayer_settings = b_use_singleplayer_settings
        self.b_allow_unlimited_respecs = b_allow_unlimited_respecs
        self.supply_crate_loot_quality_multiplier = supply_crate_loot_quality_multiplier
        self.fishing_loot_quality_multiplier = fishing_loot_quality_multiplier
        self.per_level_stats_multiplier = per_level_stats_multiplier
        self.baby_cuddle_interval_multiplier = baby_cuddle_interval_multiplier
        self.baby_cuddle_grace_period_multiplier = baby_cuddle_grace_period_multiplier
        self.baby_cuddle_lose_imprint_quality_speed_multiplier = baby_cuddle_lose_imprint_quality_speed_multiplier
        self.baby_imprinting_stat_scale_multiplier = baby_imprinting_stat_scale_multiplier
        self.player_harvesting_damage_multiplier = player_harvesting_damage_multiplier
        self.crop_growth_speed_multiplier = crop_growth_speed_multiplier
        self.baby_food_consumption_speed_multiplier = baby_food_consumption_speed_multiplier
        self.dino_class_damage_multipliers = dino_class_damage_multipliers
        self.b_pv_e_allow_tribe_war = b_pve_allow_tribe_war
        self.b_pv_e_allow_tribe_war_cancel = b_pve_allow_tribe_war_cancel
        self.crop_decay_speed_multiplier = crop_decay_speed_multiplier
        self.hair_growth_speed_multiplier = hair_growth_speed_multiplier
        self.fuel_consumption_interval_multiplier = fuel_consumption_interval_multiplier
        self.kick_idle_players_period = kick_idle_players_period
        self.max_number_of_players_in_tribe = max_number_of_players_in_tribe
        self.use_corpse_life_span_multiplier = use_corpse_life_span_multiplier
        self.global_powered_battery_durability_decrease_per_second = global_powered_battery_durability_decrease_per_second
        self.b_limit_turrets_in_range = b_limit_turrets_in_range
        self.limit_turrets_range = limit_turrets_range
        self.limit_turrets_num = limit_turrets_num
        self.b_hard_limit_turrets_in_range = b_hard_limit_turrets_in_range
        self.b_show_creative_mode = b_show_creative_mode
        self.prevent_offline_pvp_connection_invincible_interval = prevent_offline_pvp_connection_invincible_interval
        self.tamed_dino_character_food_drain_multiplier = tamed_dino_character_food_drain_multiplier
        self.wild_dino_character_food_drain_multiplier = wild_dino_character_food_drain_multiplier
        self.wild_dino_torpor_drain_multiplier = wild_dino_torpor_drain_multiplier
        self.passive_tame_interval_multiplier = passive_tame_interval_multiplier
        self.tamed_dino_torpor_drain_multiplier = tamed_dino_torpor_drain_multiplier
        self.b_ignore_structures_prevention_volumes = b_ignore_structures_prevention_volumes
        self.b_genesis_use_structures_prevention_volumes = b_genesis_use_structures_prevention_volumes
        self.b_disable_genesis_missions = b_disable_genesis_missions
        self.baby_imprint_amount_multiplier = baby_imprint_amount_multiplier
        self.hexagon_reward_multiplier = hexagon_reward_multiplier
        self.b_allow_flyer_speed_leveling = b_allow_flyer_speed_leveling
        self.prevent_transfer_for_class_names = prevent_transfer_for_class_names
        for k, v in kwargs.items():
            self.__dict__[k] = v

    def __repr__(self):
        params = [f"{k}={repr(v)}" for k, v in self.__dict__.items()]
        return f"<{self.__class__.__name__}({', '.join(params)})>"





class StartParam:
    @classmethod
    def keys_to_snakecase(cls, data: dict) -> dict:
        return {
            'pvp_structure_decay': data['PvPStructureDecay'],
            'prevent_offline_pvp': data['PreventOfflinePvP'],
            'prevent_offline_pvp_interval': data['PreventOfflinePvPInterval'],
            'show_floating_damage_text': data['ShowFloatingDamageText'],
            'disable_imprint_dino_buff': data['DisableImprintDinoBuff'],
            'allow_anyone_baby_imprint_cuddle': data['AllowAnyoneBabyImprintCuddle'],
            'overide_structure_platform_prevention': data['OverideStructurePlatformPrevention'],
            'enable_extra_structure_prevention_volumes': data['EnableExtraStructurePreventionVolumes'],
            'non_permanent_diseases': data['NonPermanentDiseases'],
            'prevent_diseases': data['PreventDiseases'],
            'override_structure_platform_prevention': data['OverrideStructurePlatformPrevention'],
            'prevent_tribe_alliances': data['PreventTribeAlliances'],
            'allow_raid_dino_feeding': data['AllowRaidDinoFeeding'],
            'allow_hit_markers': data['AllowHitMarkers'],
            'fast_decay_unsnapped_core_structures': data['FastDecayUnsnappedCoreStructures'],
            'tribe_log_destroyed_enemy_structures': data['TribeLogDestroyedEnemyStructures'],
            'override_official_difficulty': data['OverrideOfficialDifficulty'],
            'prevent_download_survivors': data['PreventDownloadSurvivors'],
            'prevent_download_items': data['PreventDownloadItems'],
            'prevent_download_dinos': data['PreventDownloadDinos'],
            'prevent_upload_survivors': data['PreventUploadSurvivors'],
            'prevent_upload_items': data['PreventUploadItems'],
            'prevent_upload_dinos': data['PreventUploadDinos'],
            'force_flyer_explosives': data['ForceFlyerExplosives'],
            'destroy_unconnected_water_pipes': data['DestroyUnconnectedWaterPipes'],
            'pvp_dino_decay': data['PvPDinoDecay'],
            'pve_allow_structures_at_supply_drops': data['PvEAllowStructuresAtSupplyDrops'],
            'allow_crate_spawns_on_top_of_structures': data['AllowCrateSpawnsOnTopOfStructures'],
            'use_optimized_harvesting_health': data['UseOptimizedHarvestingHealth'],
            'clamp_item_spoiling_times': data['ClampItemSpoilingTimes'],
            'auto_destroy_decayed_dinos': data['AutoDestroyDecayedDinos'],
            'allow_flying_stamina_recovery': data['AllowFlyingStaminaRecovery'],
            'allow_multiple_attached_c4': data['AllowMultipleAttachedC4'],
            'b_allow_platform_saddle_multi_floors': data['bAllowPlatformSaddleMultiFloors'],
            'prevent_spawn_animations': data['PreventSpawnAnimations'],
            'auto_destroy_structures': data['AutoDestroyStructures'],
            'minimum_dino_reupload_interval': data['MinimumDinoReuploadInterval'],
            'only_auto_destroy_core_structures': data['OnlyAutoDestroyCoreStructures'],
            'oxygen_swim_speed_stat_multiplier': data['OxygenSwimSpeedStatMultiplier'],
            'server_auto_force_respawn_wild_dinos_interval': data['ServerAutoForceRespawnWildDinosInterval'],
            'cross_a_r_k_allow_foreign_dino_downloads': data['CrossARKAllowForeignDinoDownloads'],
            'clamp_item_stats': data['ClampItemStats'],
            'enable_cryopod_nerf': data['EnableCryopodNerf'],
            'new_year1_utc': data['NewYear1UTC'],
            'new_year2_utc': data['NewYear2UTC'],
        }

    def __init__(
            self,
            service_id: int = None,
            pvp_structure_decay: str = None,
            prevent_offline_pvp: str = None,
            prevent_offline_pvp_interval: str = None,
            show_floating_damage_text: str = None,
            disable_imprint_dino_buff: str = None,
            allow_anyone_baby_imprint_cuddle: str = None,
            overide_structure_platform_prevention: str = None,
            enable_extra_structure_prevention_volumes: str = None,
            non_permanent_diseases: str = None,
            prevent_diseases: str = None,
            override_structure_platform_prevention: str = None,
            prevent_tribe_alliances: str = None,
            allow_raid_dino_feeding: str = None,
            allow_hit_markers: str = None,
            fast_decay_unsnapped_core_structures: str = None,
            tribe_log_destroyed_enemy_structures: str = None,
            override_official_difficulty: str = None,
            prevent_download_survivors: str = None,
            prevent_download_items: str = None,
            prevent_download_dinos: str = None,
            prevent_upload_survivors: str = None,
            prevent_upload_items: str = None,
            prevent_upload_dinos: str = None,
            force_flyer_explosives: str = None,
            destroy_unconnected_water_pipes: str = None,
            pvp_dino_decay: str = None,
            pve_allow_structures_at_supply_drops: str = None,
            allow_crate_spawns_on_top_of_structures: str = None,
            use_optimized_harvesting_health: str = None,
            clamp_item_spoiling_times: str = None,
            auto_destroy_decayed_dinos: str = None,
            allow_flying_stamina_recovery: str = None,
            allow_multiple_attached_c4: str = None,
            b_allow_platform_saddle_multi_floors: str = None,
            prevent_spawn_animations: str = None,
            auto_destroy_structures: str = None,
            minimum_dino_reupload_interval: str = None,
            only_auto_destroy_core_structures: str = None,
            oxygen_swim_speed_stat_multiplier: str = None,
            server_auto_force_respawn_wild_dinos_interval: str = None,
            cross_ark_allow_foreign_dino_downloads: str = None,
            clamp_item_stats: str = None,
            enable_cryopod_nerf: str = None,
            new_year1_utc: str = None,
            new_year2_utc: str = None,
            **kwargs
    ):
        self.service_id = service_id
        self.pvp_structure_decay = pvp_structure_decay
        self.prevent_offline_pvp = prevent_offline_pvp
        self.prevent_offline_pvp_interval = prevent_offline_pvp_interval
        self.show_floating_damage_text = show_floating_damage_text
        self.disable_imprint_dino_buff = disable_imprint_dino_buff
        self.allow_anyone_baby_imprint_cuddle = allow_anyone_baby_imprint_cuddle
        self.overide_structure_platform_prevention = overide_structure_platform_prevention
        self.enable_extra_structure_prevention_volumes = enable_extra_structure_prevention_volumes
        self.non_permanent_diseases = non_permanent_diseases
        self.prevent_diseases = prevent_diseases
        self.override_structure_platform_prevention = override_structure_platform_prevention
        self.prevent_tribe_alliances = prevent_tribe_alliances
        self.allow_raid_dino_feeding = allow_raid_dino_feeding
        self.allow_hit_markers = allow_hit_markers
        self.fast_decay_unsnapped_core_structures = fast_decay_unsnapped_core_structures
        self.tribe_log_destroyed_enemy_structures = tribe_log_destroyed_enemy_structures
        self.override_official_difficulty = override_official_difficulty
        self.prevent_download_survivors = prevent_download_survivors
        self.prevent_download_items = prevent_download_items
        self.prevent_download_dinos = prevent_download_dinos
        self.prevent_upload_survivors = prevent_upload_survivors
        self.prevent_upload_items = prevent_upload_items
        self.prevent_upload_dinos = prevent_upload_dinos
        self.force_flyer_explosives = force_flyer_explosives
        self.destroy_unconnected_water_pipes = destroy_unconnected_water_pipes
        self.pvp_dino_decay = pvp_dino_decay
        self.pve_allow_structures_at_supply_drops = pve_allow_structures_at_supply_drops
        self.allow_crate_spawns_on_top_of_structures = allow_crate_spawns_on_top_of_structures
        self.use_optimized_harvesting_health = use_optimized_harvesting_health
        self.clamp_item_spoiling_times = clamp_item_spoiling_times
        self.auto_destroy_decayed_dinos = auto_destroy_decayed_dinos
        self.allow_flying_stamina_recovery = allow_flying_stamina_recovery
        self.allow_multiple_attached_c4 = allow_multiple_attached_c4
        self.b_allow_platform_saddle_multi_floors = b_allow_platform_saddle_multi_floors
        self.prevent_spawn_animations = prevent_spawn_animations
        self.auto_destroy_structures = auto_destroy_structures
        self.minimum_dino_reupload_interval = minimum_dino_reupload_interval
        self.only_auto_destroy_core_structures = only_auto_destroy_core_structures
        self.oxygen_swim_speed_stat_multiplier = oxygen_swim_speed_stat_multiplier
        self.server_auto_force_respawn_wild_dinos_interval = server_auto_force_respawn_wild_dinos_interval
        self.cross_ark_allow_foreign_dino_downloads = cross_ark_allow_foreign_dino_downloads
        self.clamp_item_stats = clamp_item_stats
        self.enable_cryopod_nerf = enable_cryopod_nerf
        self.new_year1_utc = new_year1_utc
        self.new_year2_utc = new_year2_utc
        for k, v in kwargs.items():
            self.__dict__[k] = v

    def __repr__(self):
        params = [f"{k}={repr(v)}" for k, v in self.__dict__.items()]
        return f"<{self.__class__.__name__}({', '.join(params)})>"





class General:
    @classmethod
    def keys_to_snakecase(cls, data: dict) -> dict:
        return {
            'expert_mode': data['expertMode'],
            'battleye': data['battleye'],
            'server_language': data['server-language'],
            'vday': data['vday'],
            'mod_update_list': data['mod-update-list'],
            'mod_status_list': data['mod-status-list'],
            'gameplay_log': data['gameplay-log'],
            'force_allow_cave_flyers': data['force-allow-cave-flyers'],
            'vac': data['vac'],
            'gamesettings_saved_utc_timestamp_hidden': data['gamesettings_saved_utc_timestamp_hidden'],
            'automatic_update_mechanism': data['automatic-update-mechanism'],
            'clusterid': data['clusterid'],
            'enablecluster': data['enablecluster'],
            'primitive_plus': data['PrimitivePlus'],
            'enable_idle_player_kick': data['enable-idle-player-kick'],
            'no_anti_speed_hack': data['no-anti-speed-hack'],
            'no_biome_walls': data['no-biome-walls'],
            'notify_admin_commands_in_chat': data['notify-admin-commands-in-chat'],
            'metrics': data['metrics'],
            'cross_play': data['CrossPlay'],
            'active_event': data['ActiveEvent'],
            'structurememopts': data['structurememopts'],
            'noundermeshchecking': data['noundermeshchecking'],
            'noundermeshkilling': data['noundermeshkilling'],
            'new_year_event': data['NewYearEvent'],
            'useitemdupecheck': data['useitemdupecheck'],
        }

    def __init__(
            self,
            service_id: int = None,
            expert_mode: str = None,
            battleye: str = None,
            server_language: str = None,
            vday: str = None,
            mod_update_list: str = None,
            mod_status_list: str = None,
            gameplay_log: str = None,
            force_allow_cave_flyers: str = None,
            vac: str = None,
            gamesettings_saved_utc_timestamp_hidden: str = None,
            automatic_update_mechanism: str = None,
            clusterid: str = None,
            enablecluster: str = None,
            primitive_plus: str = None,
            enable_idle_player_kick: str = None,
            no_anti_speed_hack: str = None,
            no_biome_walls: str = None,
            notify_admin_commands_in_chat: str = None,
            metrics: str = None,
            cross_play: str = None,
            active_event: str = None,
            structurememopts: str = None,
            noundermeshchecking: str = None,
            noundermeshkilling: str = None,
            new_year_event: str = None,
            useitemdupecheck: str = None,
            **kwargs
    ):
        self.service_id = service_id
        self.expert_mode = expert_mode
        self.battleye = battleye
        self.server_language = server_language
        self.vday = vday
        self.mod_update_list = mod_update_list
        self.mod_status_list = mod_status_list
        self.gameplay_log = gameplay_log
        self.force_allow_cave_flyers = force_allow_cave_flyers
        self.vac = vac
        self.gamesettings_saved_utc_timestamp_hidden = gamesettings_saved_utc_timestamp_hidden
        self.automatic_update_mechanism = automatic_update_mechanism
        self.clusterid = clusterid
        self.enablecluster = enablecluster
        self.primitive_plus = primitive_plus
        self.enable_idle_player_kick = enable_idle_player_kick
        self.no_anti_speed_hack = no_anti_speed_hack
        self.no_biome_walls = no_biome_walls
        self.notify_admin_commands_in_chat = notify_admin_commands_in_chat
        self.metrics = metrics
        self.cross_play = cross_play
        self.active_event = active_event
        self.structurememopts = structurememopts
        self.noundermeshchecking = noundermeshchecking
        self.noundermeshkilling = noundermeshkilling
        self.new_year_event = new_year_event
        self.useitemdupecheck = useitemdupecheck
        for k, v in kwargs.items():
            self.__dict__[k] = v

    def __repr__(self):
        params = [f"{k}={repr(v)}" for k, v in self.__dict__.items()]
        return f"<{self.__class__.__name__}({', '.join(params)})>"





class Config:
    @classmethod
    def keys_to_snakecase(cls, data: dict) -> dict:
        return {
            'activate_admin_logs': data['activateAdminLogs'],
            'pve_dino_decay_period_multiplier': data['PvEDinoDecayPeriodMultiplier'],
            'player_character_water_drain_multiplier': data['PlayerCharacterWaterDrainMultiplier'],
            'time_to_collapse_rod': data['TimeToCollapseROD'],
            'harvest_amount_multiplier': data['HarvestAmountMultiplier'],
            'admin_list': data['admin-list'],
            'per_platform_max_structures_multiplier': data['PerPlatformMaxStructuresMultiplier'],
            'active_mods': data['active-mods'],
            'disable_death_spectator': data['DisableDeathSpectator'],
            'only_decay_unsnapped_core_structures': data['OnlyDecayUnsnappedCoreStructures'],
            'structure_destruction_tag': data['StructureDestructionTag'],
            'battle_sudden_death_interval': data['BattleSuddenDeathInterval'],
            'disable_structure_decay_pve': data['disable-structure-decay-pve'],
            'disable_dino_riding': data['DisableDinoRiding'],
            'allow_cave_building_pve': data['AllowCaveBuildingPvE'],
            'disable_dino_decay_pve': data['DisableDinoDecayPvE'],
            'random_supply_crate_points': data['RandomSupplyCratePoints'],
            'cryopod_nerf_duration': data['CryopodNerfDuration'],
            'game_log_buffer': data['gameLogBuffer'],
            'prevent_download_dinos': data['prevent-download-dinos'],
            'battle_auto_start_game_interval': data['BattleAutoStartGameInterval'],
            'exlusivejoin': data['exlusivejoin'],
            'map_mod_id': data['map-mod-id'],
            'only_admin_rejoin_as_spectator': data['OnlyAdminRejoinAsSpectator'],
            'allow_cave_building_pvp': data['AllowCaveBuildingPvP'],
            'hardcore': data['hardcore'],
            'default_map': data['default-map'],
            'cryopod_nerf_damage_mult': data['CryopodNerfDamageMult'],
            'allow_hide_damage_source_from_logs': data['AllowHideDamageSourceFromLogs'],
            'players_join_no_check_list': data['players-join-no-check-list'],
            'player_on_map': data['player-on-map'],
            'xp_multiplier': data['XPMultiplier'],
            'prevent_download_items': data['prevent-download-items'],
            'player_resistance_multiplier': data['PlayerResistanceMultiplier'],
            'battle_auto_restart_game_interval': data['BattleAutoRestartGameInterval'],
            'force_respawn_dinos': data['ForceRespawnDinos'],
            'b_show_status_notification_messages': data['bShowStatusNotificationMessages'],
            'clamp_resource_harvest_damage': data['ClampResourceHarvestDamage'],
            'dino_damage_multiplier': data['DinoDamageMultiplier'],
            'dino_character_health_recovery_multiplier': data['DinoCharacterHealthRecoveryMultiplier'],
            'player_character_food_drain_multiplier': data['PlayerCharacterFoodDrainMultiplier'],
            'day_cycle_speed_scale': data['DayCycleSpeedScale'],
            'server_name': data['server-name'],
            'difficulty_offset': data['difficulty-offset'],
            'restart_countdown_seconds': data['restart-countdown-seconds'],
            'motd_duration': data['motd-duration'],
            'disable_weather_fog': data['DisableWeatherFog'],
            'activate_admin_tribe_logs': data['activateAdminTribeLogs'],
            'taming_speed_multiplier': data['TamingSpeedMultiplier'],
            'tribute_dino_expiration_seconds': data['TributeDinoExpirationSeconds'],
            'player_character_health_recovery_multiplier': data['PlayerCharacterHealthRecoveryMultiplier'],
            'no_tribute_downloads': data['no-tribute-downloads'],
            'battle_num_of_tribes_to_start_game': data['BattleNumOfTribesToStartGame'],
            'enable_pvp_gamma': data['enable-pvp-gamma'],
            'disable_pve_gamma': data['DisablePvEGamma'],
            'leave_messages': data['leave-messages'],
            'active_total_conversion': data['active-total-conversion'],
            'map_expert': data['map-expert'],
            'allow_tek_suit_powers_in_genesis': data['AllowTekSuitPowersInGenesis'],
            'max_personal_tamed_dinos': data['MaxPersonalTamedDinos'],
            'dino_character_food_drain_multiplier': data['DinoCharacterFoodDrainMultiplier'],
            'day_time_speed_scale': data['DayTimeSpeedScale'],
            'map': data['map'],
            'spectator_password': data['SpectatorPassword'],
            'prevent_download_survivors': data['prevent-download-survivors'],
            'start_with_backup': data['start-with-backup'],
            'night_time_speed_scale': data['NightTimeSpeedScale'],
            'auto_destroy_old_structures_multiplier': data['AutoDestroyOldStructuresMultiplier'],
            'resources_respawn_period_multiplier': data['ResourcesRespawnPeriodMultiplier'],
            'tribe_name_change_cooldown': data['TribeNameChangeCooldown'],
            'auto_save_period_minutes': data['AutoSavePeriodMinutes'],
            'ban_list_url': data['BanListURL'],
            'third_person': data['3rd-person'],
            'force_all_structure_locking': data['ForceAllStructureLocking'],
            'ban_list': data['ban-list'],
            'disable_pvp': data['disable-pvp'],
            'dino_count_multiplier': data['DinoCountMultiplier'],
            'message_of_the_day': data['message-of-the-day'],
            'item_stack_size_multiplier': data['ItemStackSizeMultiplier'],
            'b_force_can_ride_fliers': data['bForceCanRideFliers'],
            'dino_character_stamina_drain_multiplier': data['DinoCharacterStaminaDrainMultiplier'],
            'join_messages': data['join-messages'],
            'max_structures_in_range': data['max-structures-in-range'],
            'voice_chat': data['voice-chat'],
            'dino_resistance_multiplier': data['DinoResistanceMultiplier'],
            'enable_cryo_sickness_pve': data['EnableCryoSicknessPVE'],
            'server_password': data['server-password'],
            'harvest_health_multiplier': data['HarvestHealthMultiplier'],
            'admin_password': data['admin-password'],
            'no_hud': data['no-hud'],
            'nofishloot': data['nofishloot'],
            'disable_dino_taming': data['DisableDinoTaming'],
            'player_character_stamina_drain_multiplier': data['PlayerCharacterStaminaDrainMultiplier'],
            'players_exclusive_join_list': data['PlayersExclusiveJoinList'],
            'tribute_character_expiration_seconds': data['TributeCharacterExpirationSeconds'],
            'current_admin_password': data['current-admin-password'],
            'tribute_item_expiration_seconds': data['TributeItemExpirationSeconds'],
            'player_damage_multiplier': data['PlayerDamageMultiplier'],
            'structure_resistance_multiplier': data['StructureResistanceMultiplier'],
            'crosshair': data['crosshair'],
            'near_chat_only': data['near-chat-only'],
            'pv_e_structure_decay_period_multiplier': data['PvEStructureDecayPeriodMultiplier'],
            'allow_flyer_carry_pve': data['allow-flyer-carry-pve'],
            'structure_damage_multiplier': data['StructureDamageMultiplier'],
            'b_join_notifications': data['bJoinNotifications'],
            'admin_logging': data['AdminLogging'],
        }

    def __init__(
            self,
            service_id: int = None,
            server_name: str = None,
            admin_password: str = None,
            server_password: str = None,
            player_on_map: str = None,
            disable_pvp: str = None,
            hardcore: str = None,
            crosshair: str = None,
            no_hud: str = None,
            voice_chat: str = None,
            near_chat_only: str = None,
            third_person: str = None,
            leave_messages: str = None,
            join_messages: str = None,
            message_of_the_day: str = None,
            difficulty_offset: str = None,
            motd_duration: str = None,
            disable_structure_decay_pve: str = None,
            allow_flyer_carry_pve: str = None,
            max_structures_in_range: str = None,
            enable_pvp_gamma: str = None,
            no_tribute_downloads: str = None,
            day_cycle_speed_scale: str = None,
            night_time_speed_scale: str = None,
            day_time_speed_scale: str = None,
            dino_damage_multiplier: str = None,
            player_damage_multiplier: str = None,
            structure_damage_multiplier: str = None,
            player_resistance_multiplier: str = None,
            dino_resistance_multiplier: str = None,
            structure_resistance_multiplier: str = None,
            xp_multiplier: str = None,
            taming_speed_multiplier: str = None,
            harvest_amount_multiplier: str = None,
            harvest_health_multiplier: str = None,
            player_character_water_drain_multiplier: str = None,
            player_character_food_drain_multiplier: str = None,
            dino_character_food_drain_multiplier: str = None,
            player_character_stamina_drain_multiplier: str = None,
            dino_character_stamina_drain_multiplier: str = None,
            player_character_health_recovery_multiplier: str = None,
            dino_character_health_recovery_multiplier: str = None,
            dino_count_multiplier: str = None,
            pv_e_structure_decay_period_multiplier: str = None,
            resources_respawn_period_multiplier: str = None,
            clamp_resource_harvest_damage: str = None,
            map: str = None,
            restart_countdown_seconds: str = None,
            active_mods: str = None,
            start_with_backup: str = None,
            players_join_no_check_list: str = None,
            ban_list: str = None,
            prevent_download_survivors: str = None,
            prevent_download_items: str = None,
            prevent_download_dinos: str = None,
            admin_list: str = None,
            default_map: str = None,
            map_mod_id: str = None,
            active_total_conversion: str = None,
            disable_death_spectator: str = None,
            only_admin_rejoin_as_spectator: str = None,
            battle_num_of_tribes_to_start_game: str = None,
            time_to_collapse_rod: str = None,
            battle_auto_start_game_interval: str = None,
            battle_auto_restart_game_interval: str = None,
            battle_sudden_death_interval: str = None,
            structure_destruction_tag: str = None,
            force_respawn_dinos: str = None,
            ban_list_url: str = None,
            auto_save_period_minutes: str = None,
            activate_admin_logs: str = None,
            game_log_buffer: str = None,
            map_expert: str = None,
            disable_dino_decay_pve: str = None,
            pv_e_dino_decay_period_multiplier: str = None,
            disable_pve_gamma: str = None,
            exlusivejoin: str = None,
            players_exclusive_join_list: str = None,
            force_all_structure_locking: str = None,
            auto_destroy_old_structures_multiplier: str = None,
            b_join_notifications: str = None,
            b_show_status_notification_messages: str = None,
            per_platform_max_structures_multiplier: str = None,
            spectator_password: str = None,
            allow_cave_building_pve: str = None,
            nofishloot: str = None,
            disable_dino_riding: str = None,
            disable_dino_taming: str = None,
            max_personal_tamed_dinos: str = None,
            only_decay_unsnapped_core_structures: str = None,
            tribute_item_expiration_seconds: str = None,
            tribute_dino_expiration_seconds: str = None,
            tribute_character_expiration_seconds: str = None,
            current_admin_password: str = None,
            activate_admin_tribe_logs: str = None,
            tribe_name_change_cooldown: str = None,
            allow_hide_damage_source_from_logs: str = None,
            random_supply_crate_points: str = None,
            disable_weather_fog: str = None,
            admin_logging: str = None,
            b_force_can_ride_fliers: str = None,
            allow_tek_suit_powers_in_genesis: str = None,
            enable_cryo_sickness_pve: str = None,
            cryopod_nerf_duration: str = None,
            cryopod_nerf_damage_mult: str = None,
            item_stack_size_multiplier: str = None,
            allow_cave_building_pvp: str = None,
            **kwargs
    ):
        self.service_id = service_id
        self.server_name = server_name
        self.admin_password = admin_password
        self.server_password = server_password
        self.current_admin_password = current_admin_password
        self.player_on_map = player_on_map
        self.disable_pvp = disable_pvp
        self.hardcore = hardcore
        self.crosshair = crosshair
        self.no_hud = no_hud
        self.voice_chat = voice_chat
        self.near_chat_only = near_chat_only
        self.third_person = third_person
        self.leave_messages = leave_messages
        self.join_messages = join_messages
        self.message_of_the_day = message_of_the_day
        self.difficulty_offset = difficulty_offset
        self.motd_duration = motd_duration
        self.disable_structure_decay_pve = disable_structure_decay_pve
        self.allow_flyer_carry_pve = allow_flyer_carry_pve
        self.max_structures_in_range = max_structures_in_range
        self.enable_pvp_gamma = enable_pvp_gamma
        self.no_tribute_downloads = no_tribute_downloads
        self.day_cycle_speed_scale = day_cycle_speed_scale
        self.night_time_speed_scale = night_time_speed_scale
        self.day_time_speed_scale = day_time_speed_scale
        self.dino_damage_multiplier = dino_damage_multiplier
        self.player_damage_multiplier = player_damage_multiplier
        self.structure_damage_multiplier = structure_damage_multiplier
        self.player_resistance_multiplier = player_resistance_multiplier
        self.dino_resistance_multiplier = dino_resistance_multiplier
        self.structure_resistance_multiplier = structure_resistance_multiplier
        self.xp_multiplier = xp_multiplier
        self.taming_speed_multiplier = taming_speed_multiplier
        self.harvest_amount_multiplier = harvest_amount_multiplier
        self.harvest_health_multiplier = harvest_health_multiplier
        self.player_character_water_drain_multiplier = player_character_water_drain_multiplier
        self.player_character_food_drain_multiplier = player_character_food_drain_multiplier
        self.dino_character_food_drain_multiplier = dino_character_food_drain_multiplier
        self.player_character_stamina_drain_multiplier = player_character_stamina_drain_multiplier
        self.dino_character_stamina_drain_multiplier = dino_character_stamina_drain_multiplier
        self.player_character_health_recovery_multiplier = player_character_health_recovery_multiplier
        self.dino_character_health_recovery_multiplier = dino_character_health_recovery_multiplier
        self.dino_count_multiplier = dino_count_multiplier
        self.pv_e_structure_decay_period_multiplier = pv_e_structure_decay_period_multiplier
        self.resources_respawn_period_multiplier = resources_respawn_period_multiplier
        self.clamp_resource_harvest_damage = clamp_resource_harvest_damage
        self.map = map
        self.restart_countdown_seconds = restart_countdown_seconds
        self.active_mods = active_mods
        self.start_with_backup = start_with_backup
        self.players_join_no_check_list = players_join_no_check_list
        self.ban_list = ban_list
        self.prevent_download_survivors = prevent_download_survivors
        self.prevent_download_items = prevent_download_items
        self.prevent_download_dinos = prevent_download_dinos
        self.admin_list = admin_list
        self.default_map = default_map
        self.map_mod_id = map_mod_id
        self.active_total_conversion = active_total_conversion
        self.disable_death_spectator = disable_death_spectator
        self.only_admin_rejoin_as_spectator = only_admin_rejoin_as_spectator
        self.battle_num_of_tribes_to_start_game = battle_num_of_tribes_to_start_game
        self.time_to_collapse_rod = time_to_collapse_rod
        self.battle_auto_start_game_interval = battle_auto_start_game_interval
        self.battle_auto_restart_game_interval = battle_auto_restart_game_interval
        self.battle_sudden_death_interval = battle_sudden_death_interval
        self.structure_destruction_tag = structure_destruction_tag
        self.force_respawn_dinos = force_respawn_dinos
        self.ban_list_url = ban_list_url
        self.auto_save_period_minutes = auto_save_period_minutes
        self.activate_admin_logs = activate_admin_logs
        self.game_log_buffer = game_log_buffer
        self.tribute_character_expiration_seconds = tribute_character_expiration_seconds
        self.map_expert = map_expert
        self.disable_dino_decay_pve = disable_dino_decay_pve
        self.pv_e_dino_decay_period_multiplier = pv_e_dino_decay_period_multiplier
        self.disable_pve_gamma = disable_pve_gamma
        self.exlusivejoin = exlusivejoin
        self.players_exclusive_join_list = players_exclusive_join_list
        self.force_all_structure_locking = force_all_structure_locking
        self.auto_destroy_old_structures_multiplier = auto_destroy_old_structures_multiplier
        self.b_join_notifications = b_join_notifications
        self.b_show_status_notification_messages = b_show_status_notification_messages
        self.per_platform_max_structures_multiplier = per_platform_max_structures_multiplier
        self.spectator_password = spectator_password
        self.allow_cave_building_pve = allow_cave_building_pve
        self.nofishloot = nofishloot
        self.disable_dino_riding = disable_dino_riding
        self.disable_dino_taming = disable_dino_taming
        self.max_personal_tamed_dinos = max_personal_tamed_dinos
        self.only_decay_unsnapped_core_structures = only_decay_unsnapped_core_structures
        self.tribute_item_expiration_seconds = tribute_item_expiration_seconds
        self.tribute_dino_expiration_seconds = tribute_dino_expiration_seconds
        self.activate_admin_tribe_logs = activate_admin_tribe_logs
        self.tribe_name_change_cooldown = tribe_name_change_cooldown
        self.allow_hide_damage_source_from_logs = allow_hide_damage_source_from_logs
        self.random_supply_crate_points = random_supply_crate_points
        self.disable_weather_fog = disable_weather_fog
        self.admin_logging = admin_logging
        self.b_force_can_ride_fliers = b_force_can_ride_fliers
        self.allow_tek_suit_powers_in_genesis = allow_tek_suit_powers_in_genesis
        self.enable_cryo_sickness_pve = enable_cryo_sickness_pve
        self.cryopod_nerf_duration = cryopod_nerf_duration
        self.cryopod_nerf_damage_mult = cryopod_nerf_damage_mult
        self.item_stack_size_multiplier = item_stack_size_multiplier
        self.allow_cave_building_pvp = allow_cave_building_pvp
        for k, v in kwargs.items():
            self.__dict__[k] = v

    def __repr__(self):
        params = [f"{k}={repr(v)}" for k, v in self.__dict__.items()]
        return f"<{self.__class__.__name__}({', '.join(params)})>"




from __future__ import annotations
from .config import Config
from .feature_settings import FeatureSettings
from .general import General
from .start_param import StartParam
from .game_ini import GameIni


class Settings:
    @classmethod
    def keys_to_snakecase(cls, data: dict) -> dict:
        return {
            "config": data['config'],
            "gameini": data['gameini'],
            "features": data['features'],
            "general": data['general'],
            "start_param": data['start-param'],
            "append": None if "append" in data else data['append']
        }

    def __init__(
            self,
            service_id: int = None,
            config: dict = None,
            gameini: dict = None,
            features: dict = None,
            append: dict = None,
            general: dict = None,
            start_param: dict = None,
            **kwargs
    ):
        self.service_id = service_id
        self.config = Config(service_id=service_id, **Config.keys_to_snakecase(config))
        self.gameini = GameIni(service_id=service_id, **GameIni.keys_to_snake_case(gameini))
        self.features = FeatureSettings(service_id=service_id, **FeatureSettings.keys_to_snakecase(features))
        self.append = append
        self.general = General(service_id=service_id, **General.keys_to_snakecase(general))
        self.start_param = start_param and StartParam(service_id=service_id, **StartParam.keys_to_snakecase(start_param))

        for k, v in kwargs.items():
            self.__dict__[k] = v

    def __repr__(self):
        params = [f"{k}={repr(v)}" for k, v in self.__dict__.items()]
        return f"<{self.__class__.__name__}({', '.join(params)})>"

